"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_utils_1 = require("@mlcc/core-utils");
const model_1 = require("./model");
class Block extends model_1.Model {
    /**
     * The table associated with the model.
     * @return {String}
     */
    getTable() {
        return "blocks";
    }
    /**
     * The read-only structure with query-formatting columns.
     * @return {Object}
     */
    getColumnSet() {
        return this.createColumnSet([
            {
                name: "id",
            },
            {
                name: "version",
            },
            {
                name: "timestamp",
            },
            {
                name: "previous_block",
                prop: "previousBlock",
                def: null,
            },
            {
                name: "height",
            },
            {
                name: "number_of_transactions",
                prop: "numberOfTransactions",
            },
            {
                name: "total_amount",
                prop: "totalAmount",
                init: col => core_utils_1.bignumify(col.value).toFixed(),
            },
            {
                name: "total_fee",
                prop: "totalFee",
                init: col => core_utils_1.bignumify(col.value).toFixed(),
            },
            {
                name: "reward",
                init: col => core_utils_1.bignumify(col.value).toFixed(),
            },
            {
                name: "payload_length",
                prop: "payloadLength",
            },
            {
                name: "payload_hash",
                prop: "payloadHash",
            },
            {
                name: "generator_public_key",
                prop: "generatorPublicKey",
            },
            {
                name: "block_signature",
                prop: "blockSignature",
            },
        ]);
    }
}
exports.Block = Block;
//# sourceMappingURL=block.js.map