"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sql_1 = __importDefault(require("sql"));
class Model {
    /**
     * Create a new model instance.
     * @param {Object} pgp
     */
    constructor(pgp) {
        this.pgp = pgp;
    }
    /**
     * Return the model & table definition.
     * @return {Object}
     */
    query() {
        const { schema, columns } = this.getColumnSet();
        return sql_1.default.define({
            name: this.getTable(),
            schema,
            columns: columns.map(column => ({
                name: column.name,
                prop: column.prop || column.name,
            })),
        });
    }
    /**
     * Convert the "camelCase" keys to "snake_case".
     * @return {ColumnSet}
     * @param columns
     */
    createColumnSet(columns) {
        return new this.pgp.helpers.ColumnSet(columns, {
            table: {
                table: this.getTable(),
                schema: "public",
            },
        });
    }
}
exports.Model = Model;
//# sourceMappingURL=model.js.map