"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_utils_1 = require("@mlcc/core-utils");
const model_1 = require("./model");
class Transaction extends model_1.Model {
    /**
     * The table associated with the model.
     * @return {String}
     */
    getTable() {
        return "transactions";
    }
    /**
     * The read-only structure with query-formatting columns.
     * @return {Object}
     */
    getColumnSet() {
        return this.createColumnSet([
            {
                name: "id",
            },
            {
                name: "version",
            },
            {
                name: "block_id",
                prop: "blockId",
            },
            {
                name: "sequence",
            },
            {
                name: "timestamp",
            },
            {
                name: "sender_public_key",
                prop: "senderPublicKey",
            },
            {
                name: "recipient_id",
                prop: "recipientId",
            },
            {
                name: "type",
            },
            {
                name: "vendor_field_hex",
                prop: "vendorFieldHex",
            },
            {
                name: "amount",
                init: col => core_utils_1.bignumify(col.value).toFixed(),
            },
            {
                name: "fee",
                init: col => core_utils_1.bignumify(col.value).toFixed(),
            },
            {
                name: "serialized",
                init: col => Buffer.from(col.value, "hex"),
            },
        ]);
    }
}
exports.Transaction = Transaction;
//# sourceMappingURL=transaction.js.map