"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_database_1 = require("@mlcc/core-database");
const defaults_1 = require("./defaults");
const postgres_connection_1 = require("./postgres-connection");
exports.plugin = {
    pkg: require("../package.json"),
    defaults: defaults_1.defaults,
    alias: "database",
    extends: "@mlcc/core-database",
    async register(container, options) {
        container.resolvePlugin("logger").info("Establishing Database Connection");
        const walletManager = new core_database_1.WalletManager();
        const databaseManager = container.resolvePlugin("databaseManager");
        const connection = await databaseManager.makeConnection(new postgres_connection_1.PostgresConnection(options, walletManager));
        return await core_database_1.databaseServiceFactory(options, walletManager, connection);
    },
    async deregister(container, options) {
        container.resolvePlugin("logger").info("Closing Database Connection");
        const databaseService = container.resolvePlugin("database");
        await databaseService.connection.disconnect();
    },
};
//# sourceMappingURL=plugin.js.map