import { Database } from "@mlcc/core-interfaces";
import { Block } from "../models";
import { Repository } from "./repository";
export declare class BlocksRepository extends Repository implements Database.IBlocksRepository {
    /**
     * Find a block by its ID.
     * @param  {Number} id
     * @return {Promise}
     */
    findById(id: any): Promise<any>;
    /**
     * Count the number of records in the database.
     * @return {Promise}
     */
    count(): Promise<any>;
    /**
     * Get all of the common blocks from the database.
     * @param  {Array} ids
     * @return {Promise}
     */
    common(ids: any): Promise<any>;
    /**
     * Get all of the blocks within the given height range.
     * @param  {Number} start
     * @param  {Number} end
     * @return {Promise}
     */
    headers(start: any, end: any): Promise<any>;
    /**
     * Get all of the blocks within the given height range and order them by height.
     * @param  {Number} start
     * @param  {Number} end
     * @return {Promise}
     */
    heightRange(start: any, end: any): Promise<any>;
    /**
     * Get the last created block from the database.
     * @return {Promise}
     */
    latest(): Promise<any>;
    /**
     * Get the 10 most recently created blocks from the database.
     * @return {Promise}
     */
    recent(): Promise<any>;
    /**
     * Get statistics about all blocks from the database.
     * @return {Promise}
     */
    statistics(): Promise<any>;
    /**
     * Get top count blocks
     * @return {Promise}
     */
    top(count: any): Promise<any>;
    /**
     * Delete the block from the database.
     * @param  {Number} id
     * @return {Promise}
     */
    delete(id: any): Promise<any>;
    /**
     * Get the model related to this repository.
     * @return {Block}
     */
    getModel(): Block;
}
