import { Database } from "@mlcc/core-interfaces";
import { Model } from "../models";
export declare abstract class Repository implements Database.IRepository {
    db: any;
    pgp: any;
    protected model: Model;
    /**
     * Create a new repository instance.
     * @param  {Object} db
     * @param  {Object} pgp
     */
    constructor(db: any, pgp: any);
    /**
     * Get the model related to this repository.
     * @return {Model}
     */
    abstract getModel(): Model;
    /**
     * Estimate the number of records in the table.
     * @return {Promise}
     */
    estimate(): Promise<any>;
    /**
     * Run a truncate statement on the table.
     * @return {Promise}
     */
    truncate(): Promise<any>;
    /**
     * Create one or many instances of the related models.
     * @param  {Array|Object} items
     * @return {Promise}
     */
    insert(items: any): Promise<any>;
    /**
     * Update one or many instances of the related models.
     * @param  {Array|Object} items
     * @return {Promise}
     */
    update(items: any): Promise<any>;
    /**
     * Generate an "INSERT" query for the given data.
     * @param  {Array|Object} data
     * @return {String}
     */
    __insertQuery(data: any): any;
    /**
     * Generate an "UPDATE" query for the given data.
     * @param  {Array|Object} data
     * @return {String}
     */
    __updateQuery(data: any): any;
}
