"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const queries_1 = require("../queries");
const repository_1 = require("./repository");
const { transactions: sql } = queries_1.queries;
class TransactionsRepository extends repository_1.Repository {
    /**
     * Find a transactions by its ID.
     * @param  {String} id
     * @return {Promise}
     */
    async findById(id) {
        return this.db.oneOrNone(sql.findById, { id });
    }
    /**
     * Find multiple transactionss by their block ID.
     * @param  {String} id
     * @return {Promise}
     */
    async findByBlockId(id) {
        return this.db.manyOrNone(sql.findByBlock, { id });
    }
    /**
     * Find multiple transactionss by their block ID and order them by sequence.
     * @param  {Number} id
     * @return {Promise}
     */
    async latestByBlock(id) {
        return this.db.manyOrNone(sql.latestByBlock, { id });
    }
    /**
     * Find multiple transactionss by their block IDs and order them by sequence.
     * @param  {Array} ids
     * @return {Promise}
     */
    async latestByBlocks(ids) {
        return this.db.manyOrNone(sql.latestByBlocks, { ids });
    }
    /**
     * Get all of the forged transactions from the database.
     * @param  {Array} ids
     * @return {Promise}
     */
    async forged(ids) {
        return this.db.manyOrNone(sql.forged, { ids });
    }
    /**
     * Get statistics about all transactions from the database.
     * @return {Promise}
     */
    async statistics() {
        return this.db.one(sql.statistics);
    }
    /**
     * Delete the transactions from the database.
     * @param  {Number} id
     * @return {Promise}
     */
    async deleteByBlockId(id) {
        return this.db.none(sql.deleteByBlock, { id });
    }
    /**
     * Get the model related to this repository.
     * @return {Transaction}
     */
    getModel() {
        return new models_1.Transaction(this.pgp);
    }
}
exports.TransactionsRepository = TransactionsRepository;
//# sourceMappingURL=transactions.js.map