"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const queries_1 = require("../queries");
const repository_1 = require("./repository");
const { wallets: sql } = queries_1.queries;
class WalletsRepository extends repository_1.Repository {
    /**
     * Get all of the wallets from the database.
     * @return {Promise}
     */
    async all() {
        return this.db.manyOrNone(sql.all);
    }
    /**
     * Find a wallet by its address.
     * @param  {String} address
     * @return {Promise}
     */
    async findByAddress(address) {
        return this.db.oneOrNone(sql.findByAddress, { address });
    }
    /**
     * Get the count of wallets that have a negative balance.
     * @return {Promise}
     */
    async tallyWithNegativeBalance() {
        return this.db.oneOrNone(sql.findNegativeBalances);
    }
    /**
     * Get the count of wallets that have a negative vote balance.
     * @return {Promise}
     */
    async tallyWithNegativeVoteBalance() {
        return this.db.oneOrNone(sql.findNegativeVoteBalances);
    }
    /**
     * Create or update a record matching the attributes, and fill it with values.
     * @param  {Object} wallet
     * @return {Promise}
     */
    async updateOrCreate(wallet) {
        const query = `${this.__insertQuery(wallet)} ON CONFLICT(address) DO UPDATE SET ${this.pgp.helpers.sets(wallet, this.model.getColumnSet())}`;
        return this.db.none(query);
    }
    /**
     * Get the model related to this repository.
     * @return {Object}
     */
    getModel() {
        return new models_1.Wallet(this.pgp);
    }
}
exports.WalletsRepository = WalletsRepository;
//# sourceMappingURL=wallets.js.map