import { Database } from "@mlcc/core-interfaces";
import { QueryExecutor } from "./sql/query-executor";
export declare class SPV {
    private query;
    private walletManager;
    constructor(query: QueryExecutor, walletManager: Database.IWalletManager);
    /**
     * Perform the SPV (Simple Payment Verification).
     * @param  {Number} height
     * @return {void}
     */
    build(height: any): Promise<boolean>;
    /**
     * Load and apply received transactions to wallets.
     * @return {void}
     */
    __buildReceivedTransactions(): Promise<void>;
    /**
     * Load and apply block rewards to wallets.
     * @return {void}
     */
    __buildBlockRewards(): Promise<void>;
    /**
     * Load and apply last forged blocks to wallets.
     * @return {void}
     */
    __buildLastForgedBlocks(): Promise<void>;
    /**
     * Load and apply sent transactions to wallets.
     * @return {void}
     */
    __buildSentTransactions(): Promise<void>;
    /**
     * Used to determine if a wallet is a Genesis wallet.
     * @return {Boolean}
     */
    isGenesis(wallet: any): any;
    /**
     * Load and apply second signature transactions to wallets.
     * @return {void}
     */
    __buildSecondSignatures(): Promise<void>;
    /**
     * Load and apply votes to wallets.
     * @return {void}
     */
    __buildVotes(): Promise<void>;
    /**
     * Load and apply delegate usernames to wallets.
     * @return {void}
     */
    __buildDelegates(): Promise<void>;
    /**
     * Load and apply multisignatures to wallets.
     * @return {void}
     */
    __buildMultisignatures(): Promise<void>;
    /**
     * Verify the consistency of the wallets table by comparing all records against
     * the in memory wallets.
     * NOTE: This is faster than rebuilding the entire table from scratch each time.
     * @returns {Boolean}
     */
    __verifyWalletsConsistency(): Promise<boolean>;
}
