import { PostgresConnection } from "../postgres-connection";
export declare class QueryExecutor {
    connection: PostgresConnection;
    /**
     * Create a new QueryExecutor instance.
     * @param  {[type]} connection
     * @return {QueryBuilder}
     */
    constructor(connection: PostgresConnection);
    /**
     * Execute the given query and expect no results.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    none(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query and expect one result.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    one(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query and expect one or no results.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    oneOrNone(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query and expect many results.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    many(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query and expect many or no results.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    manyOrNone(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query and expect any results.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @return {Promise}
     */
    any(query: any, parameters?: any): Promise<any>;
    /**
     * Execute the given query using the given method and parameters.
     * @param  {QueryFile} query
     * @param  {Array} parameters
     * @param  {String} method
     * @return {QueryBuilder}
     */
    __executeQueryFile(query: any, parameters: any, method: any): Promise<any>;
}
